@@ -28,6 +28,7 @@
 
 #include <sys/types.h>
 #include <dirent.h>
+#include <signal.h>
 #include <gnome.h>
 #include <cspi/spi.h>
 #include <libbonobo.h>
@@ -60,8 +61,9 @@
 #include "gok-feedback.h"
 #include "gok-modifier.h"
 #include "gok-action.h"
-#include <signal.h>
 #include "gok-bounds.h"
+#include "gok-keyslotter.h"
+#include "gok-gconf.h"
 
 #define USE_GCONF 1
 
@@ -2090,7 +2092,7 @@ gok_main_initialize_wordcomplete ()
 
     if ( !(gok_wordcomplete_open (gok_wordcomplete_get_default (),
 				  directory_name)) ||
-	 ! (gok_keyslotter_on (gok_wordcomplete_get_default (), KEYTYPE_WORDCOMPLETE))) {
+	 ! (gok_keyslotter_on (TRUE, KEYTYPE_WORDCOMPLETE))) {
 	    gok_log_x ("Error initializing word completion");
 	    
     }
